package models

import (
	"eta_gn/eta_report/global"
	"eta_gn/eta_report/utils"
	"time"
)

type ReportChapterType struct {
	ReportChapterTypeId    int       `gorm:"primaryKey;autoIncrement;column:report_chapter_type_id"`
	ReportChapterTypeKey   string    `gorm:"column:report_chapter_type_key" description:"章节key"`
	ReportChapterTypeThumb string    `gorm:"column:report_chapter_type_thumb" description:"H5展示的图片"`
	BannerUrl              string    `gorm:"column:banner_url" description:"banner显示图片"`
	ReportChapterTypeName  string    `gorm:"column:report_chapter_type_name" description:"报告章节类型名称"`
	Sort                   int       `gorm:"column:sort" description:"排序字段"`
	Enabled                int       `gorm:"column:enabled" description:"启禁用状态"`
	CreatedTime            time.Time `gorm:"column:created_time" description:"创建时间"`
	LastUpdatedTime        time.Time `gorm:"column:last_updated_time" description:"更新时间"`
	ResearchType           string    `gorm:"column:research_type" description:"研报类型"`
	SelectedImage          string    `gorm:"column:selected_image" description:"选中时的图片"`
	UnselectedImage        string    `gorm:"column:unselected_image" description:"没选中时的图片"`
	PcSelectedImage        string    `gorm:"column:pc_selected_image" description:"PC-选中的图片"`
	PcUnselectedImage      string    `gorm:"column:pc_unselected_image" description:"PC-未选中的图片"`
	EditImgUrl             string    `gorm:"column:edit_img_url" description:"管理后台编辑时选用的图"`
	TickerTitle            string    `gorm:"column:ticker_title" description:"指标列的标题"`
	IsShow                 int       `gorm:"column:is_show" description:"是否显示(研报小程序端根据此字段判断)"`
	PauseStartTime         string    `gorm:"column:pause_start_time" description:"暂停开始日期"`
	PauseEndTime           string    `gorm:"column:pause_end_time" description:"暂停结束日期"`
	IsSet                  int       `gorm:"column:is_set" description:"是否设置:0为设置,1已设置"`
	YbIconUrl              string    `gorm:"column:yb_icon_url" description:"研报小程序icon"`
	YbBottomIcon           string    `gorm:"column:yb_bottom_icon" description:"研报小程序详情底部icon"`
}

func GetAllReportChapterTypeListByResearchType(researchType string) (list []*ReportChapterType, err error) {
	if utils.BusinessCode != utils.BusinessCodeRelease {
		return
	}

	sql := ` SELECT * FROM report_chapter_type WHERE research_type = ?`
	err = global.DEFAULT_DmSQL.Raw(sql, researchType).Scan(&list).Error

	return
}
