package utils

import (
	"fmt"
	"github.com/beego/beego/v2/server/web"
	"strconv"
)

var (
	RunMode          string //运行模式
	MYSQL_URL        string //数据库连接
	MYSQL_URL_ETA    string
	MYSQL_WEEKLY_URL string //CRM主库

	REDIS_CACHE string //缓存地址
	Re error       //redis错误
	Rc RedisClient //redis缓存
)

var (
	LogPath    string //调用过程中的日志存放地址
	LogFile    string
	BinLogPath string //数据库相关的日志存放地址
	BinLogFile string
	ApiLogPath string //接口请求地址和接口返回值日志存放地址
	ApiLogFile string
	LogMaxDays int //日志最大保留天数
)

var (
	DesKey           string // 加密key
	EmailSendToUsers string // 邮件提醒人员
	BusinessCode     string // 商户号
)

var (
	EtaPubUrl string

	EtaPubAuthorization string

	AlarmMsgUrl string

	Report2ImgServerUrl string // 报告详情转图片服务地址

	ChartLibUrl string
)

var (
	ObjectStorageClient string // 目前有oss minio，默认oss
	ResourceProxyUrl    string // 代理资源地址
)

var (
	Bucketname       string
	Endpoint         string
	Imghost          string
	UploadDir        string
	Upload_Audio_Dir string
	AccessKeyId      string
	AccessKeySecret  string
)

var (
	MinIoBucketname       string
	MinIoEndpoint         string
	MinIoImghost          string
	MinIoUploadDir        string
	MinIoUpload_Audio_Dir string
	MinIoAccessKeyId      string
	MinIoAccessKeySecret  string
	MinIoUseSSL           string
	MinIoPort             string
	MinIoRegion           string
)

var (
	S3Endpoint        string
	S3BucketName      string
	S3UploadDir       string
	S3AccessKeyId     string
	S3AccessKeySecret string
	S3Host            string
	S3Region          string
	S3ForceStyle      string
	S3EndpointPort    string
	S3Protocol        string
	S3DisableSSL      string
	S3OpenAcl         string
)

func init() {
	tmpRunMode, err := web.AppConfig.String("run_mode")
	if err != nil {
		panic("配置文件读取run_mode错误 " + err.Error())
	}
	RunMode = tmpRunMode
	if RunMode == "" {
		localIp, err := GetLocalIP()
		fmt.Println("localIp:", localIp)
		if localIp == "10.0.0.123" {
			RunMode = "debug"
		} else {
			RunMode = "release"
		}
		fmt.Println("RunMode:", RunMode)
		configPath := `/home/code/config/eta_gn/eta_report/conf/app.conf`
		fmt.Println("configPath:", configPath)
		err = web.LoadAppConfig("ini", configPath)
		if err != nil {
			fmt.Println("web.LoadAppConfig Err:" + err.Error())
		}
	}

	config, err := web.AppConfig.GetSection(RunMode)
	if err != nil {
		panic("配置文件读取错误 " + err.Error())
	}
	fmt.Println(RunMode + " 模式")
	MYSQL_URL = config["mysql_url"]
	MYSQL_URL_ETA = config["mysql_url_eta"]
	MYSQL_WEEKLY_URL = config["mysql_url_weekly"]

	REDIS_CACHE = config["beego_cache"]
	if len(REDIS_CACHE) <= 0 {
		panic(any("redis链接参数没有配置"))
	}
	redisClient, err := initRedis(config["redis_type"], config["beego_cache"])
	if err != nil {
		fmt.Println("redis链接异常：", err)
		panic(any(Re))
	}
	Rc = redisClient

	{
		LogPath = config["log_path"]
		LogFile = config["log_file"]
		BinLogPath = config["binlog_path"]
		BinLogFile = config["binlog_file"]
		ApiLogPath = config["apilog_path"]
		ApiLogFile = config["apilog_file"]
		logMaxDaysStr := config["log_max_day"]
		LogMaxDays, _ = strconv.Atoi(logMaxDaysStr)
	}

	{
		DesKey = config["des_key"]

		EmailSendToUsers = config["email_send_to_users"]

		BusinessCode = config["business_code"]
	}

	{
		EtaPubUrl = config["eta_pub_url"]

		EtaPubAuthorization = config["eta_pub_authorization"]

		AlarmMsgUrl = config["alarm_msg_url"]

		Report2ImgServerUrl = config["report2img_server_url"]

		ChartLibUrl = config["chart_lib_url"]

	}

	ObjectStorageClient = config["object_storage_client"]
	ResourceProxyUrl = config["resource_proxy_url"]
	{
		Endpoint = config["endpoint"]
		Bucketname = config["bucket_name"]
		Imghost = config["img_host"]
		UploadDir = config["upload_dir"]
		Upload_Audio_Dir = config["upload_audio_dir"]
		AccessKeyId = config["access_key_id"]
		AccessKeySecret = config["access_key_secret"]
	}

	{
		MinIoEndpoint = config["minio_endpoint"]
		MinIoBucketname = config["minio_bucket_name"]
		MinIoImghost = config["minio_img_host"]
		MinIoUploadDir = config["minio_upload_dir"]
		MinIoUpload_Audio_Dir = config["minio_upload_audio_dir"]
		MinIoAccessKeyId = config["minio_access_key_id"]
		MinIoAccessKeySecret = config["minio_access_key_secret"]
		MinIoUseSSL = config["minio_use_ssl"]
		MinIoPort = config["minio_port"]
		MinIoRegion = config["minio_region"]
	}

	{
		S3Endpoint = config["s3_endpoint"]
		S3BucketName = config["s3_bucket_name"]
		S3Host = config["s3_host"]
		S3AccessKeyId = config["s3_access_key_id"]
		S3AccessKeySecret = config["s3_access_key_secret"]
		S3UploadDir = config["s3_upload_dir"]
		S3Region = config["s3_region"]
		S3ForceStyle = config["s3_force_style"]
		S3EndpointPort = config["s3_endpoint_port"]
		S3Protocol = config["s3_protocol"]
		S3DisableSSL = config["s3_disable_ssl"]
		S3OpenAcl = config["s3_open_acl"]
	}
}
